@@ -19,7 +19,7 @@
 
 /* Target triple LLVM will generate code for by default */
 /* Doesn't use `cmakedefine` because it is allowed to be empty. */
-#define LLVM_DEFAULT_TARGET_TRIPLE "riscv64-unknown-linux-gnu"
+#define LLVM_DEFAULT_TARGET_TRIPLE "powerpc64le-unknown-linux-gnu"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -28,28 +28,28 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "riscv64-unknown-linux-gnu"
+#define LLVM_HOST_TRIPLE "powerpc64le-unknown-linux-gnu"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH RISCV
+#define LLVM_NATIVE_ARCH PowerPC
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializeRISCVAsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializePowerPCAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializeRISCVAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializePowerPCAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeRISCVDisassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializePowerPCDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializeRISCVTarget
+#define LLVM_NATIVE_TARGET LLVMInitializePowerPCTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializeRISCVTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializePowerPCTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializeRISCVTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializePowerPCTargetMC
 
 /* LLVM name for the native target MCA init function, if available */
 /* #undef LLVM_NATIVE_TARGETMCA */
@@ -148,10 +148,10 @@
 #define LLVM_VERSION_MINOR 1
 
 /* Patch version of the LLVM API */
-#define LLVM_VERSION_PATCH 4
+#define LLVM_VERSION_PATCH 7
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "19.1.4"
+#define LLVM_VERSION_STRING "19.1.7"
 
 /* Whether LLVM records statistics for use with GetStatistics(),
  * PrintStatistics() or PrintStatisticsJSON()
